Summary: Tools for configuring the console (keyboard, virtual terminals, etc.)
Name: kbd
Version: 1.12
Release: 2
License: GPL
Group: System Environment/Base
Source0: ftp://ftp.kernel.org/pub/linux/utils/kbd/kbd-%{version}.tar.bz2
Source1: ftp://ftp.kernel.org/pub/linux/utils/kbd/kbd-%{version}.tar.bz2.sign
Source2: kbdrate.apps
Source3: kbdrate.pam
Source4: keytable.init
Source5: kbd-latsun-fonts.tar.bz2
Requires: pam >= 0.66-4, /etc/pam.d/system-auth, usermode
BuildRoot: %{_tmppath}/%{name}-root
Patch0: kbd-1.08-sparc.patch
Patch1: kbd-1.08-compose.patch
Patch4: kbd-1.08-terminal.patch
Patch7: kbd-1.08-rukbd.patch
Obsoletes: console-tools
Provides: console-tools
Conflicts: util-linux < 2.11r-9
Prereq: sed mktemp initscripts >= 5.86-1
ExcludeArch: s390 s390x

%description
The %{name} package contains tools for managing a Linux
system's console's behavior, including the keyboard, the screen
fonts, the virtual terminals and font files.

%prep

%setup -q -a 5
%patch0 -p1 -b .sparc
%patch1 -p1
%patch4 -p1 -b .terminal
%patch7 -p1 -b .utf8ru

# 7-bit maps are obsolete; so are non-euro maps
pushd data/keymaps/i386
mv qwerty/fi.map qwerty/fi-old.map
cp qwerty/fi-latin9.map qwerty/fi.map
cp qwerty/pt-latin9.map qwerty/pt.map
cp qwerty/sv-latin1.map qwerty/se-latin1.map

mv azerty/fr.map azerty/fr-old.map
cp azerty/fr-latin9.map azerty/fr.map

cp azerty/fr-latin9.map azerty/fr-latin0.map # legacy alias
popd

# Default to latarcyrheb-sun16 font for unicode
perl -pi -e 's/LatArCyrHeb-16/latarcyrheb-sun16/' src/unicode_start

%build
export OLD_PO_FILE_INPUT=yes

# We don't want the backups to show up on an actually installed system
# (But we want them after an rpm -bp kbd.spec, so don't remove -b)
find . -name "*.p[0-9]" |xargs rm -f

# We don't use % {configure} because the ./configure included here does not
# understand most of the options.
CFLAGS="$RPM_OPT_FLAGS"; export CFLAGS
./configure --prefix=/ --datadir=/lib/kbd --mandir=%{_mandir}

# Override CFLAGS because this configure ignores them anyway, and LDFLAGS
# because it defaults to -s, but that's a build policy decision.
make CFLAGS="$RPM_OPT_FLAGS" LDFLAGS=

%install
rm -rf $RPM_BUILD_ROOT

# Basic install.
make install \
	BINDIR=$RPM_BUILD_ROOT/%{_bindir} \
	LOADKEYS_BINDIR=$RPM_BUILD_ROOT/bin \
	MANDIR=$RPM_BUILD_ROOT/%{_mandir} \
	datadir=$RPM_BUILD_ROOT/lib/kbd \
	DATADIR=$RPM_BUILD_ROOT/lib/kbd \
	gnulocaledir=$RPM_BUILD_ROOT/%{_datadir}/locale \
	localedir=$RPM_BUILD_ROOT/%{_datadir}/locale

# Move binaries which we use before /usr is mounted from %{_bindir} to /bin.
for binary in setfont dumpkeys kbd_mode unicode_start unicode_stop ; do
  mv $RPM_BUILD_ROOT%{_bindir}/$binary $RPM_BUILD_ROOT/bin
done

# Set up kbdrate to be userhelpered.
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
mv $RPM_BUILD_ROOT%{_bindir}/kbdrate $RPM_BUILD_ROOT%{_sbindir}
ln -s consolehelper $RPM_BUILD_ROOT%{_bindir}/kbdrate
install -c -m644 $RPM_SOURCE_DIR/kbdrate.apps \
	$RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps/kbdrate
install -c -m644 $RPM_SOURCE_DIR/kbdrate.pam \
	$RPM_BUILD_ROOT%{_sysconfdir}/pam.d/kbdrate

%find_lang %{name}

%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%triggerun -- kbd < 1.08-11
/sbin/chkconfig --del keytable

%files -f %{name}.lang
%defattr(-,root,root)
%doc CHANGES CREDITS README doc/*.txt doc/kbd.FAQ*.html doc/font-formats/*.html doc/utf/utf*
/bin/*
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/*/*
/lib/kbd
%config %{_sysconfdir}/security/console.apps/*
%config %{_sysconfdir}/pam.d/*

%changelog
* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Feb 26 2004 Adrian Havill <havill@redhat.com>
- update to 1.12

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Jan 14 2004 Bill Nottingham <notting@redhat.com> 1.08-12
- remove speakup patch at request of author

* Fri Oct 10 2003 Bill Nottingham <notting@redhat.com> 1.08-11
- remove keytable init script (#106783)

* Tue Aug 12 2003 Adrian Havill <havill@rtedhat.com> 1.08-10.1
- bump for RHEL

* Tue Aug 12 2003 Adrian Havill <havill@rtedhat.com> 1.08-10
- apply the rukbd patch (#78218)

* Thu Jul 31 2003 Adrian Havill <havill@redhat.com> 1.08-9
- don't print "plus before..." warnings about non-supported capslock
  in unimode <Andries.Brouwer@cwi.nl> (#81855)

* Wed Jul 30 2003 Adrian Havill <havill@redhat.com> 1.08-8
- replaced Russian keyboard map with working UTF-8 equivalent (#79338)

* Thu Jul 24 2003 Adrian Havill <havill@redhat.com> 1.08-7
- make euro/latin-9 the default instead of latin-1 and 7-bit (#97013)
- fix swedish keymap; se, not sv (#88791)
- add fr-latin0 legacy alias of fr-latin-9 (#88324)
- add ".map" ext to filename param of init script (#90562)

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Mar 06 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- build new rpm

* Fri Feb 21 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- ExcludeArch mainframe

* Thu Jan 30 2003 Bill Nottingham <notting@redhat.com> 1.08-4
- remove condrestart from initscript

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Fri Dec  6 2002 Nalin Dahyabhai <nalin@redhat.com> 1.08-2
- only output terminal unicode init sequence if both stdout and stderr are
  connected to terminals, so that it doesn't show up when script outputs
  get piped to files

* Fri Nov 22 2002 Nalin Dahyabhai <nalin@redhat.com> 1.08-1
- update to 1.08
- drop updates which went mainline

* Mon Nov 11 2002 Nalin Dahyabhai <nalin@redhat.com> 1.06-27
- add detached signature
- remove directory names from PAM configuration so that the same config file
  can be used for any arch on multilib systems

* Wed Sep  4 2002 Bill Nottingham <notting@redhat.com> 1.06-26
- don't munge /etc/sysconfig/i18n

* Tue Sep  3 2002 Bill Nottingham <notting@redhat.com> 1.06-25
- don't run setsysfont in upgrade trigger on console-tools

* Thu Aug 29 2002 Jakub Jelinek <jakub@redhat.com> 1.06-24
- use cyr-sun16 cyrillic chars in latarcyrheb-sun16 font
  instead of old LatArCyrHeb-16 chars
- add Euro character to latarcyrheb-sun16
- use latarcyrheb-sun16 by default in unicode_start script

* Tue Aug 27 2002 Jakub Jelinek <jakub@redhat.com> 1.06-23
- add back lat[02]-sun16 fonts plus latarcyrheb-sun16 font

* Thu Aug 22 2002 Karsten Hopp <karsten@redhat.de>
- needs to conflict with older util-linux packages 
  (kbdrate moved between packages)

* Tue Aug 13 2002 Bill Nottingham <notting@redhat.com> 1.06-21
- remove Evil Hack in favor of slightly-less-evil-hack in initscripts

* Tue Jul  9 2002 Bill Nottingham <notting@redhat.com> 1.06-20
- fix speakup keymap names

* Tue Jul 09 2002 Phil Knirsch <pknirsch@redhat.com> 1.06-19
- Evil hack to make setfont work correctly on all consoles (#68018)

* Thu Jun 27 2002 Bill Nottingham <notting@redhat.com> 1.06-18
- move unicode_stop to /bin too
- fix path to loadkeys in keytable.init
- add in speakup keymaps

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue Jun 11 2002 Nalin Dahyabhai <nalin@redhat.com> 1.06-16
- fix incorrect path in console.apps configuration file

* Thu May 30 2002 Bill Nottingham <notting@redhat.com> 1.06-14
- move some more stuff to /bin (unicode_start and dependencies)

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Mon Feb 25 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-12
- Rebuild in new environment

* Wed Jan 30 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-11
- Oops, actually list the pam files in %files

* Tue Jan 29 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-10
- Add and consolehelper'ify kbdrate

* Tue Jan 29 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-9
- Re-remove kbdrate

* Thu Jan 24 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-7
- Fix build in current environment
- Get rid of kbdrate, it's in util-linux these days

* Wed Jul 18 2001 Matt Wilson <msw@redhat.com>
- added a patch (Patch4) that allows --tty= in setfont
- modified patch not to break translations

* Tue Jul  3 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-4
- Add cyrillic patches from leon@geon.donetsk.ua (#47144)

* Tue Jun 26 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-3
- Fix "Alt+AltGr=Compose" in qwertz-keyboards

* Mon Jun 25 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-2
- Fix "make install" and init script (#45327)

* Sat Jun 16 2001 Than Ngo <than@redhat.com>
- update to 1.0.6
- use %%{_tmppath}
- use find_lang
- support new gettext
- remove some patch files, which are included in 1.0.6
- fix to use RPM_OPT_FLAGS

* Thu May  3 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.05-3
- Fix up resizecons

* Wed May  2 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.05-2
- Build everything, obsoletes console-tools
- s/Copyright:/License:/
- License is GPL, not just distributable
- Add our compose mappings from old console-tools
- Add triggerpostun -- console-tools magic to get sane fonts and mappings

* Tue Apr 17 2001 Erik Troan <ewt@redhat.com>
- initial packaging for kbdrate
